@@ -42,7 +42,9 @@ def read_list(text,value_list=None,sep = ',',modifier_list_not=None,test_number
     result_list = list()
     elem_list = text.split(sep)
     for x in  elem_list:
-        if ignore_quote == False :
+        if ignore_quote :
+            elem = x.strip()
+        else:
             elem = x.strip().strip("'\"")
         if test_number :
             elem = number_test(elem)
